/**
 * Copyright (C) 2010 OSGi fuer Praktiker <info@osgi-buch.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package biz.gossipmonger.skilledworker.internal;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;

import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;

import org.osgi.framework.BundleContext;

public class HtmlRenderer {
	private BundleContext bundleContext;
	
	public HtmlRenderer(BundleContext bundleContext) {
		this.bundleContext = bundleContext;
	}

  public File render(InputStream is, String inputFilename, String outputDir) throws IOException {
		File outputFile = createOutputFile(inputFilename, outputDir);
		URL xsltFileUrl = bundleContext.getBundle().getResource("stylesheet.xslt");
		if (xsltFileUrl == null) {
			throw new IOException("stylesheet.xslt not contained in bundle.");
		}
		try {
			Source xsltSource = new StreamSource(xsltFileUrl.openStream());
			TransformerFactory transformerFactory = TransformerFactory.newInstance();
			Transformer transformer = transformerFactory.newTransformer(xsltSource);
			transformer.transform(new StreamSource(is), new StreamResult(new FileOutputStream(outputFile)));
			return outputFile;
		} catch (Exception e) {
			throw new IOException(e);
		}
  }

  private File createOutputFile(String inputFilename, String outputDir) throws IOException {
    File file = new File(inputFilename);
    String name = file.getName();
    String basename = name.replaceFirst("(.*)\\.[^.]*", "$1.html");
    File outputDirFile = new File(outputDir);
    if (!outputDirFile.exists() && !outputDirFile.mkdirs()) {
      throw new IOException("Could not create directory " + outputDirFile.getAbsolutePath());
    }
    return new File(outputDir, basename);
  }
}
