/**
 * Copyright (C) ${year} OSGi für Praktiker <info@osgi-buch.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package biz.gossipmonger.jobtimer;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileWriter;
import java.io.IOException;
import java.util.InputMismatchException;
import java.util.Scanner;

import org.osgi.framework.BundleContext;

public class JobTimerConfig
             implements JobTimerConfigMBean {

  private int interval;
  String filename = "interval";
  File file = null;

  public JobTimerConfig(BundleContext context) {
    interval = 10000;
    file = context.getDataFile(filename);
    if (!(file == null))
      try {
        Scanner in = new Scanner(file);
        if (in.hasNext())
          interval = in.nextInt();
      } catch (FileNotFoundException e) {
        System.out.println("Cannot read interval from"
                           +" file. Using default.");
      }  catch (InputMismatchException e) {
        System.out.println("Did not find an int in"
                           +" interval file.");
      }
    else
      System.out.println("getDataFile is not supported"
                         +" on this platform");
  }

  public int getInterval() {
    return this.interval;
  }
  public void setInterval(int interval) {
    this.interval = interval;
    if (!(file == null)) {
      try {
        FileWriter out = new FileWriter(file);
        out.write("" + interval);
        out.flush();
      } catch (IOException e) {
        System.out.println("Cannot write interval to"
                           +" file.");
      }
    }
  }

}
